==> camel-k-model-v1-5.10.0-sources.jar: io/fabric8/camelk/v1/Task.java <==

package io.fabric8.camelk.v1;

import java.util.HashMap;
import java.util.Map;
import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import io.fabric8.kubernetes.api.model.Container;
import io.fabric8.kubernetes.api.model.ContainerPort;
import io.fabric8.kubernetes.api.model.EnvVar;
import io.fabric8.kubernetes.api.model.KubernetesResource;
import io.fabric8.kubernetes.api.model.LabelSelector;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectReference;
import io.fabric8.kubernetes.api.model.Volume;
import io.fabric8.kubernetes.api.model.VolumeMount;
import io.sundr.builder.annotations.Buildable;
import io.sundr.builder.annotations.BuildableReference;
import lombok.EqualsAndHashCode;
import lombok.Setter;
import lombok.ToString;
import lombok.experimental.Accessors;

@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonPropertyOrder({
    "builder",
    "image"
})
@JsonDeserialize(using = com.fasterxml.jackson.databind.JsonDeserializer.None.class)
@ToString
@EqualsAndHashCode
@Setter
@Accessors(prefix = {
    "_",
    ""
})
@Buildable(editableEnabled = false, validationEnabled = false, generateBuilderPackage = false, builderPackage = "io.fabric8.kubernetes.api.builder", refs = {
    @BuildableReference(ObjectMeta.class),
    @BuildableReference(ObjectReference.class),
    @BuildableReference(LabelSelector.class),
    @BuildableReference(Container.class),
    @BuildableReference(EnvVar.class),
    @BuildableReference(ContainerPort.class),
    @BuildableReference(Volume.class),
    @BuildableReference(VolumeMount.class)
})
public class Task implements KubernetesResource
{

    @JsonProperty("builder")
    private BuilderTask builder;
    @JsonProperty("image")
    private ImageTask image;
    @JsonIgnore
    private Map<String, Object> additionalProperties = new HashMap<String, Object>();

    /**
     * No args constructor for use in serialization
     * 
     */
    public Task() {
    }

    /**
     * 
     * @param image
     * @param builder
     */
    public Task(BuilderTask builder, ImageTask image) {
        super();
        this.builder = builder;
        this.image = image;
    }

    @JsonProperty("builder")
    public BuilderTask getBuilder() {
        return builder;
    }

    @JsonProperty("builder")
    public void setBuilder(BuilderTask builder) {
        this.builder = builder;
    }

    @JsonProperty("image")
    public ImageTask getImage() {
        return image;
    }

    @JsonProperty("image")
    public void setImage(ImageTask image) {
        this.image = image;
    }

    @JsonAnyGetter
    public Map<String, Object> getAdditionalProperties() {
        return this.additionalProperties;
    }

    @JsonAnySetter
    public void setAdditionalProperty(String name, Object value) {
        this.additionalProperties.put(name, value);
    }

}

==> camel-k-model-v1-5.12.3-sources.jar: io/fabric8/camelk/v1/Task.java <==

package io.fabric8.camelk.v1;

import java.util.HashMap;
import java.util.Map;
import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import io.fabric8.kubernetes.api.model.Container;
import io.fabric8.kubernetes.api.model.ContainerPort;
import io.fabric8.kubernetes.api.model.EnvVar;
import io.fabric8.kubernetes.api.model.KubernetesResource;
import io.fabric8.kubernetes.api.model.LabelSelector;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectReference;
import io.fabric8.kubernetes.api.model.Volume;
import io.fabric8.kubernetes.api.model.VolumeMount;
import io.sundr.builder.annotations.Buildable;
import io.sundr.builder.annotations.BuildableReference;
import lombok.EqualsAndHashCode;
import lombok.Setter;
import lombok.ToString;
import lombok.experimental.Accessors;

@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonPropertyOrder({
    "buildah",
    "builder",
    "kaniko",
    "s2i",
    "spectrum"
})
@JsonDeserialize(using = com.fasterxml.jackson.databind.JsonDeserializer.None.class)
@ToString
@EqualsAndHashCode
@Setter
@Accessors(prefix = {
    "_",
    ""
})
@Buildable(editableEnabled = false, validationEnabled = false, generateBuilderPackage = false, builderPackage = "io.fabric8.kubernetes.api.builder", refs = {
    @BuildableReference(ObjectMeta.class),
    @BuildableReference(ObjectReference.class),
    @BuildableReference(LabelSelector.class),
    @BuildableReference(Container.class),
    @BuildableReference(EnvVar.class),
    @BuildableReference(ContainerPort.class),
    @BuildableReference(Volume.class),
    @BuildableReference(VolumeMount.class)
})
public class Task implements KubernetesResource
{

    @JsonProperty("buildah")
    private BuildahTask buildah;
    @JsonProperty("builder")
    private BuilderTask builder;
    @JsonProperty("kaniko")
    private KanikoTask kaniko;
    @JsonProperty("s2i")
    private S2iTask s2i;
    @JsonProperty("spectrum")
    private SpectrumTask spectrum;
    @JsonIgnore
    private Map<String, Object> additionalProperties = new HashMap<String, Object>();

    /**
     * No args constructor for use in serialization
     * 
     */
    public Task() {
    }

    /**
     * 
     * @param kaniko
     * @param spectrum
     * @param buildah
     * @param builder
     * @param s2i
     */
    public Task(BuildahTask buildah, BuilderTask builder, KanikoTask kaniko, S2iTask s2i, SpectrumTask spectrum) {
        super();
        this.buildah = buildah;
        this.builder = builder;
        this.kaniko = kaniko;
        this.s2i = s2i;
        this.spectrum = spectrum;
    }

    @JsonProperty("buildah")
    public BuildahTask getBuildah() {
        return buildah;
    }

    @JsonProperty("buildah")
    public void setBuildah(BuildahTask buildah) {
        this.buildah = buildah;
    }

    @JsonProperty("builder")
    public BuilderTask getBuilder() {
        return builder;
    }

    @JsonProperty("builder")
    public void setBuilder(BuilderTask builder) {
        this.builder = builder;
    }

    @JsonProperty("kaniko")
    public KanikoTask getKaniko() {
        return kaniko;
    }

    @JsonProperty("kaniko")
    public void setKaniko(KanikoTask kaniko) {
        this.kaniko = kaniko;
    }

    @JsonProperty("s2i")
    public S2iTask getS2i() {
        return s2i;
    }

    @JsonProperty("s2i")
    public void setS2i(S2iTask s2i) {
        this.s2i = s2i;
    }

    @JsonProperty("spectrum")
    public SpectrumTask getSpectrum() {
        return spectrum;
    }

    @JsonProperty("spectrum")
    public void setSpectrum(SpectrumTask spectrum) {
        this.spectrum = spectrum;
    }

    @JsonAnyGetter
    public Map<String, Object> getAdditionalProperties() {
        return this.additionalProperties;
    }

    @JsonAnySetter
    public void setAdditionalProperty(String name, Object value) {
        this.additionalProperties.put(name, value);
    }

}
